package UR::Namespace::Command::List::Objects;

use strict;
use warnings;

use above "UR";

class UR::Namespace::Command::List::Objects { 
  is =>  'UR::Object::Command::List',
};

1;

#$HeadURL: svn+ssh://svn/srv/svn/gscpan/distro/ur-bundle/releases/UR-0.5/lib/UR/Namespace/Command/List/Objects.pm $
#$Id: Objects.pm 36327 2008-07-08 20:59:29Z ebelter $
